import { MpBox } from '@mekari/pixel-box';
import { MpFlex } from '@mekari/pixel-flex';
import { MpText } from '@mekari/pixel-text';
import { MpIcon } from '@mekari/pixel-icon';
import { MpButton } from '@mekari/pixel-button';
import { MpButtonIcon } from '@mekari/pixel-button-icon';
import { createStyledAttrsMixin, useId } from '@mekari/pixel-utils';

/**
 * Broadcast component is global information for our users in the app. Apply on all pages and should be above of everything else.
 *
 * @category Feedback - Component
 * @see Docs - https://storybook.mekari.design/?path=/docs/components-broadcast--playground
 * @see NPMJS - https://www.npmjs.com/package/@mekari/pixel-broadcast
 */

const MpBroadcast = {
  name: 'MpBroadcast',
  mixins: [createStyledAttrsMixin('MpBroadcast')],
  props: {
    id: {
      type: String
    },
    variant: {
      type: String,
      default: 'announcement'
    },
    content: {
      type: String
    },
    textLink: {
      type: String
    },
    textLinkHref: {
      type: String
    },
    iconName: {
      type: String
    },
    textAdditionalAction: {
      type: String
    },
    hasAdditionalAction: {
      type: Boolean,
      default: false
    },
    isClosable: {
      type: Boolean,
      default: false
    }
  },
  computed: {
    getId() {
      return this.id || `broadcast-${useId()}`;
    },

    getVariant() {
      if (this.variant === 'information') {
        return {
          background: 'violet.400',
          color: 'white'
        };
      }

      if (this.variant === 'important') {
        return {
          background: 'amber.100',
          color: 'dark'
        };
      }

      return {
        background: 'stone.400',
        color: 'white'
      };
    },

    getMaxWidthContent() {
      let actionWidth = 0;

      if (this.hasAdditionalAction) {
        actionWidth += 112;
      }

      if (this.isClosable) {
        actionWidth += 42;
      }

      return `calc(100% - ${actionWidth}px)`;
    }

  },
  methods: {
    onClickAdditionalAction(e) {
      this.$emit('click-additional-action', e);
    },

    onClickTextLink(e) {
      this.$emit('click-text-link', e);
    },

    onClickCloseButton(e) {
      this.$emit('click-close-button', e);
    }

  },

  render(h) {
    return h(MpBox, {
      attrs: {
        id: this.getId,
        width: 'full',
        position: 'relative',
        'data-pixel-component': 'MpBroadcast',
        ...this.splitProps.styleAttrs,
        ...this.computedAttrs
      }
    }, [h(MpFlex, {
      props: {
        direction: 'row',
        align: 'center',
        justify: 'space-between'
      },
      attrs: {
        paddingY: '2',
        paddingX: '6',
        background: this.getVariant.background
      }
    }, [h(MpFlex, {
      props: {
        direction: 'row',
        align: 'center'
      },
      attrs: {
        width: this.getMaxWidthContent
      }
    }, [this.variant !== 'announcement' && this.iconName && h(MpIcon, {
      props: {
        name: this.iconName,
        color: this.getVariant.color,
        variant: 'fill',
        size: 'md'
      },
      attrs: {
        mr: '3'
      }
    }), h(MpText, {
      props: {
        isTruncated: true
      },
      attrs: {
        color: this.getVariant.color
      }
    }, this.content), this.textLink && h(MpText, {
      props: {
        as: 'a',
        color: this.getVariant.color
      },
      attrs: {
        flex: 'none',
        color: this.getVariant.color,
        href: this.textLinkHref,
        fontWeight: 'semibold',
        textDecoration: 'underline',
        ml: '3'
      },
      nativeOn: {
        click: this.onClickTextLink
      }
    }, this.textLink)]), h(MpFlex, {
      props: {
        direction: 'row',
        align: 'center'
      }
    }, [this.hasAdditionalAction && h(MpButton, {
      props: {
        variant: 'outline',
        size: 'sm',
        ariaLabelBy: this.textAdditionalAction
      },
      on: {
        click: this.onClickAdditionalAction
      }
    }, this.textAdditionalAction), this.variant !== 'important' && this.isClosable && h(MpButtonIcon, {
      props: {
        name: 'close',
        ariaLabel: 'Close Button',
        isHoverable: false
      },
      attrs: {
        ml: '3',
        color: 'white',
        _hover: {
          color: this.getVariant.color
        }
      },
      on: {
        click: this.onClickCloseButton
      }
    })])])]);
  }

};

export { MpBroadcast };
